paralegal_non_rustc_utils

Struct TruncatedHumanTime

pub struct TruncatedHumanTime(pub(crate) Duration);
A struct with a Display implementation taht renders a std::time::Duration in human readable form, similar to the humantime crate, but instead of rendering with arbitrary precision it only renders two “significant sections”, e.g. “2h 5min” or “2d 20h”. The sections are days (d), hours (h), minutes (min), seconds (s), miliseconds (ms), microseconds (μs) and nanoseconds (ns).

Tuple Fields

0: Duration